@@ -29,9 +29,6 @@ var group__spa__log =
     [ "SPA_VERSION_LOG_TOPIC", "group__spa__log.html#ga3ad08caaedbf23933f4c994cc732ca28", null ],
     [ "SPA_VERSION_LOG_METHODS", "group__spa__log.html#ga750a6ac2af9bf84c4b59af14d6cbe22f", null ],
     [ "SPA_LOG_TOPIC", "group__spa__log.html#ga3442b393034c388313d9251a2cea7188", null ],
-    [ "spa_log_topic_init", "group__spa__log.html#gac791827eec92f1c14c2fe712cf95fc69", null ],
-    [ "spa_log_level_enabled", "group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6", null ],
-    [ "spa_log_level_topic_enabled", "group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6", null ],
     [ "spa_log_logt", "group__spa__log.html#gafa9a4c220c748c40bfa06de50c834416", null ],
     [ "spa_log_logtv", "group__spa__log.html#ga9b5e43d9eae0e03aba5f126d31839cf1", null ],
     [ "spa_logt_lev", "group__spa__log.html#ga0adfc889b560d62cbb2e6f8aa6c209b2", null ],
@@ -67,5 +64,7 @@ var group__spa__log =
     [ "spa_log_impl_logt", "group__spa__log.html#ga73863d235426379d73a1defd3191877c", null ],
     [ "spa_log_impl_logv", "group__spa__log.html#gac7db20d119aac7855ba0964b7f997456", null ],
     [ "spa_log_impl_log", "group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d", null ],
-    [ "spa_log_impl_topic_init", "group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1", null ]
+    [ "spa_log_impl_topic_init", "group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1", null ],
+    [ "spa_log_topic_init", "group__spa__log.html#ga27c63143b76b30a9f832c6b6f85aba5b", null ],
+    [ "spa_log_level_topic_enabled", "group__spa__log.html#ga87438994ca507ad320a1cab54bfb6af0", null ]
 ];
\ No newline at end of file
