@@ -570,29 +570,29 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "alloc_8h.html",
-"group__pw__client.html#gae9c05c6686aa7db3f69466363e7b8077",
-"group__pw__global.html#ga37767f3d8d027ae10433a0801cab0dda",
-"group__pw__keys.html#ga7e12dd6c9dec4a345c8a2a62f138b5bf",
-"group__pw__module.html#ga8c4bfe6ad4da2e2443ba7985ae7527cb",
-"group__pw__resource.html#ga61e286d92a2f528ebe48cb1436ac4eba",
-"group__pw__thread__loop.html#gabdc2e68dfd070fe58770143f184fc026",
-"group__spa__cpu.html#ga34a7cfa724239e524fdccf570249abf3",
-"group__spa__hooks.html#gab5d20379dc8a8a17e58631045e3f6323",
-"group__spa__names.html",
-"group__spa__param.html#ga162e4f18a3415d721d749fe7967b0142",
-"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a5103ce7ecf8e164734b6dd50f0dfeb93",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81af096b47f86c0d581f5370984452f04c4",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaf75aecd6d1e2ed22d4a5da51bfde53f5",
-"group__spa__pod.html#ga77acabfebad965007133387bed64922d",
-"group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf",
-"page_dma_buf.html#autotoc_md301",
-"page_pulseaudio.html#autotoc_md281",
-"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740",
-"structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a",
-"structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6",
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0",
-"structspa__meta__cursor.html#a46bdd5e6f3d880a74ae602e596176028",
-"structspa__system__methods.html#a4cd27e2c3a8daa1705da0028af779060"
+"group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
+"group__pw__global.html#ga3e5b2dd59d6cf7c614c3ed24b041a8b7",
+"group__pw__keys.html#ga7e7975fdc1d4879492d18bd5737fc7d7",
+"group__pw__module.html#ga9a9305a5898d1480d8a542f300743ed6",
+"group__pw__resource.html#ga69d44482d7bb5e6fbb95a66ccce009ed",
+"group__pw__thread__loop.html#gacb9c26a513d752803fd272a4ea2bc891",
+"group__spa__cpu.html#ga36f54e2aac3837cb3631db07cbfde3e2",
+"group__spa__hooks.html#gacb30a0a53954eed2af8041a1882eef15",
+"group__spa__names.html#ga0847db019357b78b2fda5d40da8f2d39",
+"group__spa__param.html#ga16dbda7d0628b8d175072a57204690f4",
+"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a543e3dea7d916ae7b51816b39da54806",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81afec5c9d4cb1dc263bc4a05291230422c",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaafe6fcd3875b89a15c1743a6ee8bab31c",
+"group__spa__pod.html#ga78e4ab314854074b4dd30344de63077b",
+"group__spa__types.html#ga7991023e0704b7af71b19a08c4a023b7",
+"page_library.html",
+"page_pulseaudio.html#autotoc_md283",
+"structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404",
+"structpw__impl__node__events.html#a8a7823893c92e2d190c14aa220b71be8",
+"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660",
+"structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0",
+"structspa__meta__cursor.html#a78b7805e66e52164fc8a985578b4c990",
+"structspa__system__methods.html#a74ee473681fb6c5c83693d2be53f18db"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
