@@ -24,8 +24,8 @@ var NAVTREEINDEX0 =
 "compare_8h.html":[10,8,0,2],
 "conf_8h.html":[10,6,1,0],
 "control_2type-info_8h.html":[10,8,2,1],
-"core_8h.html":[10,4,14,0],
 "core_8h.html":[10,4,4,0],
+"core_8h.html":[10,4,14,0],
 "cpu_8h.html":[10,8,9,0,0],
 "data-loop_8h.html":[10,5,11,0],
 "dbus_8h.html":[10,8,9,1,0],
@@ -42,8 +42,8 @@ var NAVTREEINDEX0 =
 "export-spa_8c-example.html":[13,22],
 "factory_8h.html":[10,4,6,0],
 "format-types_8h.html":[10,8,7,10],
-"functions.html":[11,2,0,0],
 "functions.html":[11,2,0],
+"functions.html":[11,2,0,0],
 "functions_a.html":[11,2,0,1],
 "functions_b.html":[11,2,0,2],
 "functions_c.html":[11,2,0,3],
@@ -66,8 +66,8 @@ var NAVTREEINDEX0 =
 "functions_t.html":[11,2,0,20],
 "functions_u.html":[11,2,0,21],
 "functions_v.html":[11,2,0,22],
-"functions_vars.html":[11,2,1,0],
 "functions_vars.html":[11,2,1],
+"functions_vars.html":[11,2,1,0],
 "functions_vars_a.html":[11,2,1,1],
 "functions_vars_b.html":[11,2,1,2],
 "functions_vars_c.html":[11,2,1,3],
@@ -149,28 +149,27 @@ var NAVTREEINDEX0 =
 "globals_eval_t.html":[12,5,14],
 "globals_eval_v.html":[12,5,15],
 "globals_f.html":[12,0,6],
-"globals_func.html":[12,1],
 "globals_func.html":[12,1,0],
-"globals_func_a.html":[12,1,1],
-"globals_func_b.html":[12,1,2],
-"globals_func_c.html":[12,1,3],
-"globals_func_d.html":[12,1,4],
-"globals_func_e.html":[12,1,5],
-"globals_func_f.html":[12,1,6],
-"globals_func_g.html":[12,1,7],
-"globals_func_h.html":[12,1,8],
-"globals_func_i.html":[12,1,9],
-"globals_func_j.html":[12,1,10],
-"globals_func_l.html":[12,1,11],
-"globals_func_m.html":[12,1,12],
-"globals_func_n.html":[12,1,13],
-"globals_func_p.html":[12,1,14],
-"globals_func_r.html":[12,1,15],
-"globals_func_s.html":[12,1,16],
-"globals_func_t.html":[12,1,17],
-"globals_func_u.html":[12,1,18],
-"globals_func_v.html":[12,1,19],
-"globals_func_w.html":[12,1,20],
+"globals_func.html":[12,1],
+"globals_func_b.html":[12,1,1],
+"globals_func_c.html":[12,1,2],
+"globals_func_d.html":[12,1,3],
+"globals_func_e.html":[12,1,4],
+"globals_func_f.html":[12,1,5],
+"globals_func_g.html":[12,1,6],
+"globals_func_h.html":[12,1,7],
+"globals_func_i.html":[12,1,8],
+"globals_func_j.html":[12,1,9],
+"globals_func_l.html":[12,1,10],
+"globals_func_m.html":[12,1,11],
+"globals_func_n.html":[12,1,12],
+"globals_func_p.html":[12,1,13],
+"globals_func_r.html":[12,1,14],
+"globals_func_s.html":[12,1,15],
+"globals_func_t.html":[12,1,16],
+"globals_func_u.html":[12,1,17],
+"globals_func_v.html":[12,1,18],
+"globals_func_w.html":[12,1,19],
 "globals_g.html":[12,0,7],
 "globals_h.html":[12,0,8],
 "globals_i.html":[12,0,9],
@@ -249,5 +248,6 @@ var NAVTREEINDEX0 =
 "group__pw__client.html#gaca741a1eb7d2306a1d06f7236bdcdd53":[10,4,3,24],
 "group__pw__client.html#gad6b676ec28f1d8598d37c3b73a4f06b9":[10,4,3,26],
 "group__pw__client.html#gad7327a543c437159816d4256e84e370b":[10,4,3,17],
-"group__pw__client.html#gae4b0f81c2ec7e2249624a5f3bbe3db2d":[10,4,3,9]
+"group__pw__client.html#gae4b0f81c2ec7e2249624a5f3bbe3db2d":[10,4,3,9],
+"group__pw__client.html#gae9c05c6686aa7db3f69466363e7b8077":[10,4,3,13]
 };
