@@ -1,7 +1,5 @@
 var NAVTREEINDEX15 =
 {
-"group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf":[10,8,8,12,11],
-"group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf":[10,8,8,12,19],
 "group__spa__types.html#ga7991023e0704b7af71b19a08c4a023b7":[10,8,8,12,7],
 "group__spa__types.html#ga886514f37da7215fa5eebe406e2f3b37":[10,8,8,12,5],
 "group__spa__types.html#ga8d234c1fa75de54561de75610f091efa":[10,8,8,12,15],
@@ -152,8 +150,8 @@ var NAVTREEINDEX15 =
 "group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[10,8,8,1,83,0],
 "group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[10,8,8,1,83,1],
 "h264_8h.html":[10,8,7,30],
-"hook_8h.html":[10,8,8,4,0],
 "hook_8h.html":[10,8,8,5,0],
+"hook_8h.html":[10,8,8,4,0],
 "iec958_8h.html":[10,8,7,2],
 "impl-client_8h.html":[10,5,0,0],
 "impl-core_8h.html":[10,5,1,0],
@@ -249,5 +247,7 @@ var NAVTREEINDEX15 =
 "page_dma_buf.html#autotoc_md297":[5,10,0,4],
 "page_dma_buf.html#autotoc_md298":[5,10,1],
 "page_dma_buf.html#autotoc_md299":[5,10,2],
-"page_dma_buf.html#autotoc_md300":[5,10,3]
+"page_dma_buf.html#autotoc_md300":[5,10,3],
+"page_dma_buf.html#autotoc_md301":[5,10,4],
+"page_examples.html":[7,7]
 };
