@@ -1,7 +1,5 @@
 var NAVTREEINDEX17 =
 {
-"page_pulseaudio.html#autotoc_md281":[5,16,0],
-"page_pulseaudio.html#autotoc_md282":[5,16,0,0],
 "page_pulseaudio.html#autotoc_md283":[5,16,0,1],
 "page_pulseaudio.html#autotoc_md284":[5,16,1],
 "page_pulseaudio.html#autotoc_md285":[5,16,1,0],
@@ -249,5 +247,7 @@ var NAVTREEINDEX17 =
 "structpw__client__node__events.html#ac0b5a3c66103be01b784464d4dd81fa0":[10,7,0,2,6],
 "structpw__client__node__events.html#ac5884f60926b382728097c8846dcba85":[10,7,0,2,2],
 "structpw__client__node__events.html#ad7084094ae633b01409033ba363ef78b":[10,7,0,2,1],
-"structpw__client__node__methods.html":[10,7,0,3]
+"structpw__client__node__methods.html":[10,7,0,3],
+"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740":[10,7,0,3,6],
+"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e":[10,7,0,3,1]
 };
