@@ -1,7 +1,5 @@
 var NAVTREEINDEX18 =
 {
-"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740":[10,7,0,3,6],
-"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e":[10,7,0,3,1],
 "structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404":[10,7,0,3,2],
 "structpw__client__node__methods.html#a1db43e226468e68a6a52292aa6a894c6":[10,7,0,3,7],
 "structpw__client__node__methods.html#acf64a3bd71fd790592e41458a4793c62":[10,7,0,3,0],
@@ -177,8 +175,8 @@ var NAVTREEINDEX18 =
 "structpw__filter__events.html#aca5d0df9b247219e850a94be2bf9d135":[10,1,1,5],
 "structpw__filter__events.html#adb8416b044c19f8856dac1d2b554f32a":[10,1,1,1],
 "structpw__filter__events.html#afb8a57497ec76189b2fd247ce72966c5":[10,1,1,2],
-"structpw__global.html":[10,4,2,4],
 "structpw__global.html":[10,5,12,2],
+"structpw__global.html":[10,4,2,4],
 "structpw__global__events.html":[10,5,12,1],
 "structpw__global__events.html#a57040ccb9805bda67581693d06c0cea6":[10,5,12,1,2],
 "structpw__global__events.html#a8ccd4e331a4c1a0401e13ab3c9b04236":[10,5,12,1,1],
@@ -249,5 +247,7 @@ var NAVTREEINDEX18 =
 "structpw__impl__node__events.html#a347372b746a4f05fc0a6d8ecb1346dd6":[10,5,7,1,4],
 "structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f":[10,5,7,1,15],
 "structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463":[10,5,7,1,12],
-"structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430":[10,5,7,1,0]
+"structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430":[10,5,7,1,0],
+"structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a":[10,5,7,1,2],
+"structpw__impl__node__events.html#a8a268deab9a29164fc8f9b57a9ee55e7":[10,5,7,1,8]
 };
