@@ -1,7 +1,5 @@
 var NAVTREEINDEX21 =
 {
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0":[10,8,4,5,4],
-"structspa__dict.html":[10,8,8,2,2],
 "structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0":[10,8,8,2,2,2],
 "structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399":[10,8,8,2,2,1],
 "structspa__dict.html#a88aca003fcdbc47599ffb3e2737f1a69":[10,8,8,2,2,0],
@@ -249,5 +247,7 @@ var NAVTREEINDEX21 =
 "structspa__meta__control.html":[10,8,1,13],
 "structspa__meta__control.html#a906715cf9e6709fcd23de4aef7c1dd4a":[10,8,1,13,0],
 "structspa__meta__cursor.html":[10,8,1,12],
-"structspa__meta__cursor.html#a01ee3f6baba19d1a0851a44badd819a9":[10,8,1,12,1]
+"structspa__meta__cursor.html#a01ee3f6baba19d1a0851a44badd819a9":[10,8,1,12,1],
+"structspa__meta__cursor.html#a46bdd5e6f3d880a74ae602e596176028":[10,8,1,12,3],
+"structspa__meta__cursor.html#a5f190ab6e828890a8c5b530cb9cae78d":[10,8,1,12,0]
 };
