@@ -1,6 +1,5 @@
 var NAVTREEINDEX8 =
 {
-"group__spa__hooks.html#gab5d20379dc8a8a17e58631045e3f6323":[10,8,8,4,13],
 "group__spa__hooks.html#gacb30a0a53954eed2af8041a1882eef15":[10,8,8,4,14],
 "group__spa__hooks.html#gacbc74f9ceab3dc7c5d6d8c3eca6a41e5":[10,8,8,4,12],
 "group__spa__hooks.html#gadb7d27ebaa8d5997c5420910de1db773":[10,8,8,4,4],
@@ -154,53 +153,52 @@ var NAVTREEINDEX8 =
 "group__spa__list.html#gaf76607bd5d48aa7b41d693260a19b68e":[10,8,8,3,5],
 "group__spa__list.html#gafbca4263c0f4f6afba58f226bfb99198":[10,8,8,3,26],
 "group__spa__log.html":[10,8,9,3],
-"group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6":[10,8,9,3,16],
-"group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d":[10,8,9,3,40],
-"group__spa__log.html#ga0adfc889b560d62cbb2e6f8aa6c209b2":[10,8,9,3,19],
+"group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d":[10,8,9,3,37],
+"group__spa__log.html#ga0adfc889b560d62cbb2e6f8aa6c209b2":[10,8,9,3,16],
 "group__spa__log.html#ga0b5b333c2b7fbc5470f7ec68944e20a1":[10,8,9,3,8],
-"group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d":[10,8,9,3,44],
-"group__spa__log.html#ga142802024be8a40bef345806d498d6b6":[10,8,9,3,27],
-"group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14":[10,8,9,3,37],
-"group__spa__log.html#ga24e95908846b410227578abfc63b0bf0":[10,8,9,3,32],
-"group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1":[10,8,9,3,45],
-"group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8":[10,8,9,3,33],
+"group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d":[10,8,9,3,41],
+"group__spa__log.html#ga142802024be8a40bef345806d498d6b6":[10,8,9,3,24],
+"group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14":[10,8,9,3,34],
+"group__spa__log.html#ga24e95908846b410227578abfc63b0bf0":[10,8,9,3,29],
+"group__spa__log.html#ga27c63143b76b30a9f832c6b6f85aba5b":[10,8,9,3,43],
+"group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1":[10,8,9,3,42],
+"group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8":[10,8,9,3,30],
 "group__spa__log.html#ga2cb43866ec2798103989dcafd611f28f":[10,8,9,3,7],
 "group__spa__log.html#ga3442b393034c388313d9251a2cea7188":[10,8,9,3,13],
 "group__spa__log.html#ga3ad08caaedbf23933f4c994cc732ca28":[10,8,9,3,11],
-"group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6":[10,8,9,3,34],
-"group__spa__log.html#ga4d1859244f14f1c31f0f5e446bed3cfc":[10,8,9,3,30],
+"group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6":[10,8,9,3,31],
+"group__spa__log.html#ga4d1859244f14f1c31f0f5e446bed3cfc":[10,8,9,3,27],
 "group__spa__log.html#ga54294a1ab30713deee27d8165fb7bd67":[10,8,9,3,6],
-"group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8":[10,8,9,3,41],
-"group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e":[10,8,9,3,35],
-"group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6":[10,8,9,3,15],
-"group__spa__log.html#ga73863d235426379d73a1defd3191877c":[10,8,9,3,42],
+"group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8":[10,8,9,3,38],
+"group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e":[10,8,9,3,32],
+"group__spa__log.html#ga73863d235426379d73a1defd3191877c":[10,8,9,3,39],
 "group__spa__log.html#ga750a6ac2af9bf84c4b59af14d6cbe22f":[10,8,9,3,12],
-"group__spa__log.html#ga7d4019336333f5cdf8b82514a6865b79":[10,8,9,3,39],
-"group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6":[10,8,9,3,25],
-"group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72":[10,8,9,3,26],
+"group__spa__log.html#ga7d4019336333f5cdf8b82514a6865b79":[10,8,9,3,36],
+"group__spa__log.html#ga87438994ca507ad320a1cab54bfb6af0":[10,8,9,3,44],
+"group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6":[10,8,9,3,22],
+"group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72":[10,8,9,3,23],
 "group__spa__log.html#ga9680fab963b6dc9daf3c1cf2464e53f1":[10,8,9,3,5],
-"group__spa__log.html#ga9b5e43d9eae0e03aba5f126d31839cf1":[10,8,9,3,18],
-"group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db":[10,8,9,3,22],
-"group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a":[10,8,9,3,36],
+"group__spa__log.html#ga9b5e43d9eae0e03aba5f126d31839cf1":[10,8,9,3,15],
+"group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db":[10,8,9,3,19],
+"group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a":[10,8,9,3,33],
 "group__spa__log.html#gaae4067126110801d47890be91be83c5e":[10,8,9,3,9],
-"group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620":[10,8,9,3,24],
+"group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620":[10,8,9,3,21],
 "group__spa__log.html#gab60b078a5687f091f11d951899e7c270":[10,8,9,3,10],
-"group__spa__log.html#gabcb64e94f29685ea7c529aac6a2c7b68":[10,8,9,3,29],
-"group__spa__log.html#gac791827eec92f1c14c2fe712cf95fc69":[10,8,9,3,14],
-"group__spa__log.html#gac7db20d119aac7855ba0964b7f997456":[10,8,9,3,43],
-"group__spa__log.html#gad713020cdea3eba904cfe2ce3b0c2a42":[10,8,9,3,28],
-"group__spa__log.html#gadb7117c17ee965bf745dd919800ba060":[10,8,9,3,31],
-"group__spa__log.html#gae61e34c11a6ccd1b42d570a2f1b8f018":[10,8,9,3,38],
-"group__spa__log.html#gae788ec36d61ff6a6bde516d50840999e":[10,8,9,3,20],
-"group__spa__log.html#gaecb106a06ce6f59e5f9300e641f222e4":[10,8,9,3,23],
-"group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2":[10,8,9,3,21],
-"group__spa__log.html#gafa9a4c220c748c40bfa06de50c834416":[10,8,9,3,17],
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0575748692644545c2e6177ce3cf8a6f":[10,8,9,3,40,3],
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0adcef912e39004ada04bf45a525c0fd":[10,8,9,3,40,0],
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da48610bd0a0ae2d8415da4f761eea2662":[10,8,9,3,40,5],
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da87c2c8407ce8ef06f5bbb99ef92cc034":[10,8,9,3,40,4],
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114":[10,8,9,3,40,1],
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64":[10,8,9,3,40,2],
+"group__spa__log.html#gabcb64e94f29685ea7c529aac6a2c7b68":[10,8,9,3,26],
+"group__spa__log.html#gac7db20d119aac7855ba0964b7f997456":[10,8,9,3,40],
+"group__spa__log.html#gad713020cdea3eba904cfe2ce3b0c2a42":[10,8,9,3,25],
+"group__spa__log.html#gadb7117c17ee965bf745dd919800ba060":[10,8,9,3,28],
+"group__spa__log.html#gae61e34c11a6ccd1b42d570a2f1b8f018":[10,8,9,3,35],
+"group__spa__log.html#gae788ec36d61ff6a6bde516d50840999e":[10,8,9,3,17],
+"group__spa__log.html#gaecb106a06ce6f59e5f9300e641f222e4":[10,8,9,3,20],
+"group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2":[10,8,9,3,18],
+"group__spa__log.html#gafa9a4c220c748c40bfa06de50c834416":[10,8,9,3,14],
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0575748692644545c2e6177ce3cf8a6f":[10,8,9,3,37,3],
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0adcef912e39004ada04bf45a525c0fd":[10,8,9,3,37,0],
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da48610bd0a0ae2d8415da4f761eea2662":[10,8,9,3,37,5],
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da87c2c8407ce8ef06f5bbb99ef92cc034":[10,8,9,3,37,4],
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114":[10,8,9,3,37,1],
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64":[10,8,9,3,37,2],
 "group__spa__loop.html":[10,8,9,4],
 "group__spa__loop.html#ga0f531ff1357bf1f6ad225faa1f99b265":[10,8,9,4,26],
 "group__spa__loop.html#ga11a4d14721eeda99243ae1b90b8e3bc3":[10,8,9,4,23],
@@ -249,5 +247,7 @@ var NAVTREEINDEX8 =
 "group__spa__loop.html#gaf18adfccc510004e0438614046e58013":[10,8,9,4,40],
 "group__spa__loop.html#gaf67b95b170f125ee503fec3640b727ca":[10,8,9,4,44],
 "group__spa__loop.html#gafdc6876cd766fafc297841accedcd105":[10,8,9,4,34],
-"group__spa__loop.html#gaffe08d7788d04fa44c44fda7ab3649bb":[10,8,9,4,30]
+"group__spa__loop.html#gaffe08d7788d04fa44c44fda7ab3649bb":[10,8,9,4,30],
+"group__spa__names.html":[10,8,8,8],
+"group__spa__names.html#ga010bfd1f2c50f4927df733f5f13e5690":[10,8,8,8,23]
 };
